@@ -3,4 +3,4 @@
 # We call back to autogen.sh, but with -x
 # to have some more debug
 
-exec bash -ex ./autogen.sh
+exec bash -ex ./autogen.sh --from=make
